@@ -13,9 +13,13 @@ REQUIRED_AUTOMAKE_VERSION=1.9
     exit 1
 }
 
-
 which mate-autogen || {
-    echo "You need to install mate-common from the MATE CVS"
+    echo "You need to install mate-common"
+    exit 1
+}
+
+which yelp-build || {
+    echo "You need to install yelp-tools"
     exit 1
 }
 
